==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedMap__241SynchronizedMapEntry.h <==
// class java.util.Collections$SynchronizedMap$1SynchronizedMapEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class be5feb2429b45f1 java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_
#define _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collections__24SynchronizedMap$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object;

typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$_init$6fe4615328058315(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_util_Collections__24SynchronizedMap$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
extern jint _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs {
	struct _jc_object	*e;
	struct _jc_java_util_Collections__24SynchronizedMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs {
    _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object {
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedMap__241SynchronizedMapEntry.h <==
// class java.util.Collections$SynchronizedMap$1SynchronizedMapEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class be5feb2429b45f1 java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_
#define _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collections__24SynchronizedMap$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object;

typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$_init$6fe4615328058315(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_util_Collections__24SynchronizedMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vmethods	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs {
	struct _jc_object	*e;
	struct _jc_java_util_Collections__24SynchronizedMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs {
    _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_refs	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$sub_nonrefs	java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$object {
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$vtype _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedMap__241SynchronizedMapEntry_H_ */
